@@ -158,6 +158,39 @@ class LoadMaster(HttpClient):
     def __repr__(self):
         return '{}:{}'.format(self.ip_address, self.port)
 
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self.version == other.version
+        else:
+            return False
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __gt__(self, other):
+        if isinstance(other, self.__class__):
+            return self.version > other.version
+        else:
+            return False
+
+    def __lt__(self, other):
+        if isinstance(other, self.__class__):
+            return self.version < other.version
+        else:
+            return False
+
+    def __ge__(self, other):
+        if isinstance(other, self.__class__):
+            return self.version >= other.version
+        else:
+            return False
+
+    def __le__(self, other):
+        if isinstance(other, self.__class__):
+            return self.version <= other.version
+        else:
+            return False
+
     @property
     def endpoint(self):
         if self.cert:
